% file: cfbVamp.m
% SLiCAP-MATLAB script file
% You should call this script from the file that performs the 
% initialization of a project for your SLiCAP-MATLAB work.
% You need to store this file as well as the circuit file(s) 
% in the project directory.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
checkCircuit('cfbVamp'); % - reads and checks the circuit 
                         % - creates the matrices    
                         % - creates an html index page for this circuit
source('V1');            % assign 'V1' as signal source
detector('V_4');         % assign a voltage detector that measures
                         % the voltage between node '4' and node '0' 
simType('symbolic');     % set the simulation type to 'symbolic'
gainType('gain');        % set the gain type to 'gain'   
dataType('laplace');     % set the data type to 'laplace'
result = execute();      % assign the results to the variable 'result'    
gain = simplify(result.results(1));
                         % extract the expression from the structured array
                         % and assign it to the variable 'gain'
% file: cfbVamp.m %%%%%%%% Calculations with G1 as loop gain reference %%%%
lgRef('G1');             % set 'G1' as loop gain reference
gainType('asymptotic');  % set the gain type to 'asymptotic'
result = execute();      % assign results to the variable 'result' 
AG1 = simplify(result.results(1)); % store expression in variable 'AG1'
gainType('loopgain');    % set the gain type to 'loopgain'
result = execute();      % assign results to the variable 'result' 
LG1 = simplify(result.results(1)); % store expression in variable 'LG1'
gainType('servo');       % set the gain type to 'servo'
result = execute();      % assign results to the variable 'result' 
SG1 = simplify(result.results(1)); % store expression in variable 'SG1'
gainType('direct');      % set the gain type to 'direct'
result = execute();      % assign results to the variable 'result' 
DG1 = simplify(result.results(1)); % store expression in variable 'DG1'
%%%%%%%%%%%%%%%%%%%%%%%%%% HTML page results G1 as loop gain reference %%%%
htmlPage('Asymptotic gain model G1 ref.'); 
text2html('The gain of the system can be obtained as:'); 
syms 'V_ell' 'V_s';
eqn2html(V_ell/V_s, gain);
syms 'L_G1' 'rho_G1' 'S_G1' 'A_infty_G1' 'A_f'
text2html('The asymptotic gain $A_{\\infty G1}$ is found as:'); 
eqn2html(A_infty_G1, AG1);
text2html('The loop gain $L_{G1}$ is found as:');
eqn2html(L_G1, LG1);
text2html('The servo function $S_{G1}$ is found as:');
eqn2html(S_G1, SG1);
text2html('The direct transfer $\\rho_{G1}$ is found as:');
eqn2html(rho_G1, DG1);
text2html(['If we calculate the gain $A_f$ from the asymptotic gain, '...
  'the servo function and the direct transfer, we obtain:']);
eqn2html(A_f, simplify(AG1*SG1 + DG1/(1-LG1)));
% file: cfbVamp.m %%%%%%%% Calculations with H1 as loop gain reference %%%%
lgRef('H1');             % set 'H1' as loop gain reference
gainType('asymptotic');  % set the gain type to 'asymptotic'
result = execute();      % assign results to the variable 'result' 
AH1 = simplify(result.results(1)); % store expression in variable 'AH1'
gainType('loopgain');    % set the gain type to 'loopgain'
result = execute();      % assign results to the variable 'result' 
LH1 = simplify(result.results(1)); % store expression in variable 'LH1'
gainType('servo');       % set the gain type to 'servo'
result = execute();      % assign results to the variable 'result' 
SH1 = simplify(result.results(1)); % store expression in variable 'SH1'
gainType('direct');      % set the gain type to 'direct'
result = execute();      % assign results to the variable 'result' 
DH1 = simplify(result.results(1)); % store expression in variable 'DH1'
%%%%%%%%%%%%%%%%%%%%%%%%%% HTML page results G1 as loop gain reference %%%%
htmlPage('asymptotic gain model H1 ref.'); 
text2html('The gain of the system can be obtained as:'); 
syms 'V_ell' 'V_s';
eqn2html(V_ell/V_s, gain);
syms 'L_H1' 'rho_H1' 'S_H1' 'A_infty_H1'
text2html('The asymptotic gain $A_{\\infty H1}$ is found as:'); 
eqn2html(A_infty_H1, AH1);
text2html('The loop gain $L_{H1}$ is found as:');
eqn2html(L_H1, LH1);
text2html('The servo function $S_{H1}$ is found as:');
eqn2html(S_H1, SH1);
text2html('The direct transfer $\\rho_{H1}$ is found as:');
eqn2html(rho_H1, DH1);
text2html(['If we calculate the gain $A_f$ from the asymptotic gain, '...
  'the servo function and the direct transfer, we obtain:']);
eqn2html(A_f, simplify(expand((AH1*SH1 + DH1/(1-LH1)))));
stophtml                 % close the current html page 
